@@ -20,10 +20,15 @@ import java.util.List;
 
 /**
  * Some constants and other global data that are used by the compiler and the runtime.
+ *
+ * @author Anil K. Vijendran
+ * @author Harish Prabandham
+ * @author Shawn Bayern
+ * @author Mark Roth
  */
 public class Constants {
 
-    public static final String SPEC_VERSION = "3.1";
+    public static final String SPEC_VERSION = "4.0";
 
     /**
      * These classes/packages are automatically imported by the generated code.
@@ -46,11 +51,6 @@ public class Constants {
      */
     public static final int MAX_POOL_SIZE = 5;
 
-    /**
-     * Has security been turned on?
-     */
-    public static final boolean IS_SECURITY_ENABLED = (System.getSecurityManager() != null);
-
     /**
      * Name of the system property containing the tomcat product installation path
      */
