@@ -33,6 +33,13 @@ import org.xml.sax.InputSource;
 
 /**
  * This class has all the utility method(s). Ideally should move all the bean containers here.
+ *
+ * @author Mandar Raje.
+ * @author Rajiv Mordani.
+ * @author Danno Ferrin
+ * @author Pierre Delisle
+ * @author Shawn Bayern
+ * @author Mark Roth
  */
 public class JspUtil {
 
@@ -250,28 +257,18 @@ public class JspUtil {
             type = type.substring(0, i0);
         }
 
-        Class<?> c = null;
-        if ("boolean".equals(type)) {
-            c = boolean.class;
-        } else if ("char".equals(type)) {
-            c = char.class;
-        } else if ("byte".equals(type)) {
-            c = byte.class;
-        } else if ("short".equals(type)) {
-            c = short.class;
-        } else if ("int".equals(type)) {
-            c = int.class;
-        } else if ("long".equals(type)) {
-            c = long.class;
-        } else if ("float".equals(type)) {
-            c = float.class;
-        } else if ("double".equals(type)) {
-            c = double.class;
-        } else if ("void".equals(type)) {
-            c = void.class;
-        } else {
-            c = loader.loadClass(type);
-        }
+        Class<?> c = switch (type) {
+            case "boolean" -> boolean.class;
+            case "char" -> char.class;
+            case "byte" -> byte.class;
+            case "short" -> short.class;
+            case "int" -> int.class;
+            case "long" -> long.class;
+            case "float" -> float.class;
+            case "double" -> double.class;
+            case "void" -> void.class;
+            default -> loader.loadClass(type);
+        };
 
         if (dims == 0) {
             return c;
@@ -677,7 +674,7 @@ public class JspUtil {
         StringBuilder legalClassNames = new StringBuilder();
         for (String classNameComponent : classNameComponents) {
             if (!classNameComponent.isEmpty()) {
-                if (legalClassNames.length() > 0) {
+                if (!legalClassNames.isEmpty()) {
                     legalClassNames.append('.');
                 }
                 legalClassNames.append(makeJavaIdentifier(classNameComponent));
@@ -845,35 +842,18 @@ public class JspUtil {
             if (type.charAt(i) == '[') {
                 dims++;
             } else {
-                switch (type.charAt(i)) {
-                    case 'Z':
-                        t = "boolean";
-                        break;
-                    case 'B':
-                        t = "byte";
-                        break;
-                    case 'C':
-                        t = "char";
-                        break;
-                    case 'D':
-                        t = "double";
-                        break;
-                    case 'F':
-                        t = "float";
-                        break;
-                    case 'I':
-                        t = "int";
-                        break;
-                    case 'J':
-                        t = "long";
-                        break;
-                    case 'S':
-                        t = "short";
-                        break;
-                    case 'L':
-                        t = type.substring(i + 1, type.indexOf(';'));
-                        break;
-                }
+                t = switch (type.charAt(i)) {
+                    case 'Z' -> "boolean";
+                    case 'B' -> "byte";
+                    case 'C' -> "char";
+                    case 'D' -> "double";
+                    case 'F' -> "float";
+                    case 'I' -> "int";
+                    case 'J' -> "long";
+                    case 'S' -> "short";
+                    case 'L' -> type.substring(i + 1, type.indexOf(';'));
+                    default -> null;
+                };
                 break;
             }
         }
