@@ -24,6 +24,7 @@ import java.util.Iterator;
 import java.util.List;
 import java.util.Locale;
 import java.util.Map;
+import java.util.Objects;
 import java.util.regex.Matcher;
 import java.util.regex.Pattern;
 
@@ -66,16 +67,15 @@ class Validator {
 
         private final ErrorDispatcher err;
 
-        private static final JspUtil.ValidAttribute[] pageDirectiveAttrs =
-                { new JspUtil.ValidAttribute("language"), new JspUtil.ValidAttribute("extends"),
-                        new JspUtil.ValidAttribute("import"), new JspUtil.ValidAttribute("session"),
-                        new JspUtil.ValidAttribute("buffer"), new JspUtil.ValidAttribute("autoFlush"),
-                        new JspUtil.ValidAttribute("isThreadSafe"), new JspUtil.ValidAttribute("info"),
-                        new JspUtil.ValidAttribute("errorPage"), new JspUtil.ValidAttribute("isErrorPage"),
-                        new JspUtil.ValidAttribute("contentType"), new JspUtil.ValidAttribute("pageEncoding"),
-                        new JspUtil.ValidAttribute("isELIgnored"), new JspUtil.ValidAttribute("errorOnELNotFound"),
-                        new JspUtil.ValidAttribute("deferredSyntaxAllowedAsLiteral"),
-                        new JspUtil.ValidAttribute("trimDirectiveWhitespaces") };
+        private static final JspUtil.ValidAttribute[] pageDirectiveAttrs = { new JspUtil.ValidAttribute("language"),
+                new JspUtil.ValidAttribute("extends"), new JspUtil.ValidAttribute("import"),
+                new JspUtil.ValidAttribute("session"), new JspUtil.ValidAttribute("buffer"),
+                new JspUtil.ValidAttribute("autoFlush"), new JspUtil.ValidAttribute("info"),
+                new JspUtil.ValidAttribute("errorPage"), new JspUtil.ValidAttribute("isErrorPage"),
+                new JspUtil.ValidAttribute("contentType"), new JspUtil.ValidAttribute("pageEncoding"),
+                new JspUtil.ValidAttribute("isELIgnored"), new JspUtil.ValidAttribute("errorOnELNotFound"),
+                new JspUtil.ValidAttribute("deferredSyntaxAllowedAsLiteral"),
+                new JspUtil.ValidAttribute("trimDirectiveWhitespaces") };
 
         private boolean pageEncodingSeen = false;
 
@@ -144,12 +144,6 @@ class Validator {
                     } else if (!pageInfo.getAutoFlush().equals(value)) {
                         err.jspError(n, "jsp.error.page.conflict.autoflush", pageInfo.getAutoFlush(), value);
                     }
-                } else if ("isThreadSafe".equals(attr)) {
-                    if (pageInfo.getIsThreadSafe() == null) {
-                        pageInfo.setIsThreadSafe(value, n, err);
-                    } else if (!pageInfo.getIsThreadSafe().equals(value)) {
-                        err.jspError(n, "jsp.error.page.conflict.isthreadsafe", pageInfo.getIsThreadSafe(), value);
-                    }
                 } else if ("isELIgnored".equals(attr)) {
                     if (pageInfo.getIsELIgnored() == null) {
                         pageInfo.setIsELIgnored(value, n, err, true);
@@ -410,14 +404,6 @@ class Validator {
                 new JspUtil.ValidAttribute("scope"), new JspUtil.ValidAttribute("class"),
                 new JspUtil.ValidAttribute("type"), new JspUtil.ValidAttribute("beanName", false) };
 
-        private static final JspUtil.ValidAttribute[] plugInAttrs = { new JspUtil.ValidAttribute("type", true),
-                new JspUtil.ValidAttribute("code", true), new JspUtil.ValidAttribute("codebase"),
-                new JspUtil.ValidAttribute("align"), new JspUtil.ValidAttribute("archive"),
-                new JspUtil.ValidAttribute("height", false), new JspUtil.ValidAttribute("hspace"),
-                new JspUtil.ValidAttribute("jreversion"), new JspUtil.ValidAttribute("name"),
-                new JspUtil.ValidAttribute("vspace"), new JspUtil.ValidAttribute("width", false),
-                new JspUtil.ValidAttribute("nspluginurl"), new JspUtil.ValidAttribute("iepluginurl") };
-
         private static final JspUtil.ValidAttribute[] attributeAttrs = { new JspUtil.ValidAttribute("name", true),
                 new JspUtil.ValidAttribute("trim"), new JspUtil.ValidAttribute("omit") };
 
@@ -452,7 +438,8 @@ class Validator {
             JspUtil.checkAttributes("Jsp:root", n, jspRootAttrs, err);
             String version = n.getTextAttribute("version");
             if (!version.equals("1.2") && !version.equals("2.0") && !version.equals("2.1") && !version.equals("2.2") &&
-                    !version.equals("2.3") && !version.equals("3.0") && !version.equals("3.1")) {
+                    !version.equals("2.3") && !version.equals("3.0") && !version.equals("3.1") &&
+                    !version.equals("4.0")) {
                 err.jspError(n, "jsp.error.jsproot.version.invalid", version);
             }
             visitBody(n);
@@ -488,16 +475,6 @@ class Validator {
             visitBody(n);
         }
 
-        @Override
-        public void visit(Node.ParamsAction n) throws JasperException {
-            // Make sure we've got at least one nested jsp:param
-            Node.Nodes subElems = n.getBody();
-            if (subElems == null) {
-                err.jspError(n, "jsp.error.params.emptyBody");
-            }
-            visitBody(n);
-        }
-
         @Override
         public void visit(Node.IncludeAction n) throws JasperException {
             JspUtil.checkAttributes("Include action", n, includeActionAttrs, err);
@@ -579,45 +556,6 @@ class Validator {
             visitBody(n);
         }
 
-        @SuppressWarnings("null") // type can't be null after initial test
-        @Override
-        public void visit(Node.PlugIn n) throws JasperException {
-            JspUtil.checkAttributes("Plugin", n, plugInAttrs, err);
-
-            throwErrorIfExpression(n, "type", "jsp:plugin");
-            throwErrorIfExpression(n, "code", "jsp:plugin");
-            throwErrorIfExpression(n, "codebase", "jsp:plugin");
-            throwErrorIfExpression(n, "align", "jsp:plugin");
-            throwErrorIfExpression(n, "archive", "jsp:plugin");
-            throwErrorIfExpression(n, "hspace", "jsp:plugin");
-            throwErrorIfExpression(n, "jreversion", "jsp:plugin");
-            throwErrorIfExpression(n, "name", "jsp:plugin");
-            throwErrorIfExpression(n, "vspace", "jsp:plugin");
-            throwErrorIfExpression(n, "nspluginurl", "jsp:plugin");
-            throwErrorIfExpression(n, "iepluginurl", "jsp:plugin");
-
-            String type = n.getTextAttribute("type");
-            if (type == null) {
-                err.jspError(n, "jsp.error.plugin.notype");
-            }
-            if (!type.equals("bean") && !type.equals("applet")) {
-                err.jspError(n, "jsp.error.plugin.badtype");
-            }
-            if (n.getTextAttribute("code") == null) {
-                err.jspError(n, "jsp.error.plugin.nocode");
-            }
-
-            Node.JspAttribute width =
-                    getJspAttribute(null, "width", null, null, n.getAttributeValue("width"), n, null, false);
-            n.setWidth(width);
-
-            Node.JspAttribute height =
-                    getJspAttribute(null, "height", null, null, n.getAttributeValue("height"), n, null, false);
-            n.setHeight(height);
-
-            visitBody(n);
-        }
-
         @Override
         public void visit(Node.NamedAttribute n) throws JasperException {
             JspUtil.checkAttributes("Attribute", n, attributeAttrs, err);
@@ -721,10 +659,8 @@ class Validator {
                 char c = value.charAt(i);
                 if (c == '#' && (i + 1) < len && value.charAt(i + 1) == '{' && !prevCharIsEscape) {
                     return true;
-                } else if (c == '\\') {
-                    prevCharIsEscape = true;
                 } else {
-                    prevCharIsEscape = false;
+                    prevCharIsEscape = c == '\\';
                 }
                 i++;
             }
@@ -1026,7 +962,7 @@ class Validator {
                 }
                 for (int j = 0; tldAttrs != null && j < tldAttrs.length; j++) {
                     if (attrs.getLocalName(i).equals(tldAttrs[j].getName()) && (attrs.getURI(i) == null ||
-                            attrs.getURI(i).length() == 0 || attrs.getURI(i).equals(n.getURI()))) {
+                            attrs.getURI(i).isEmpty() || attrs.getURI(i).equals(n.getURI()))) {
 
                         TagAttributeInfo tldAttr = tldAttrs[j];
                         if (tldAttr.canBeRequestTime() || tldAttr.isDeferredMethod() || tldAttr.isDeferredValue()) { // JSP
@@ -1155,7 +1091,7 @@ class Validator {
                      */
                     String attrPrefix = na.getPrefix();
                     if (na.getLocalName().equals(tldAttr.getName()) &&
-                            (attrPrefix == null || attrPrefix.length() == 0 || attrPrefix.equals(n.getPrefix()))) {
+                            (attrPrefix == null || attrPrefix.isEmpty() || attrPrefix.equals(n.getPrefix()))) {
                         jspAttrs[start + i] = new Node.JspAttribute(na, tldAttr, false);
                         NamedAttributeVisitor nav = null;
                         if (na.getBody() != null) {
@@ -1184,10 +1120,10 @@ class Validator {
         /**
          * Preprocess attributes that can be expressions. Expression delimiters are stripped.
          * <p>
-         * If value is null, checks if there are any NamedAttribute subelements in the tree node, and if so, constructs
+         * If value is null, checks if there are any NamedAttribute sub elements in the tree node, and if so, constructs
          * a JspAttribute out of a child NamedAttribute node.
          *
-         * @param el EL expression, if already parsed by the caller (so that we can skip re-parsing it)
+         * @param el EL expression, if already parsed by the caller (so that we can skip reparsing it)
          */
         private Node.JspAttribute getJspAttribute(TagAttributeInfo tai, String qName, String uri, String localName,
                 String value, Node n, ELNode.Nodes el, boolean dynamic) throws JasperException {
@@ -1252,7 +1188,7 @@ class Validator {
                     result = new Node.JspAttribute(tai, qName, uri, localName, value, false, el, dynamic);
 
                     if (el != null) {
-                        ELContextImpl ctx = new ELContextImpl(expressionFactory);
+                        ELContextImpl ctx = new ELContextImpl();
                         ctx.setFunctionMapper(getFunctionMapper(el));
 
                         try {
@@ -1385,7 +1321,7 @@ class Validator {
 
             class FVVisitor extends ELNode.Visitor {
 
-                private Node n;
+                private final Node n;
 
                 FVVisitor(Node n) {
                     this.n = n;
@@ -1435,7 +1371,7 @@ class Validator {
             validateFunctions(el, n);
 
             // test it out
-            ELContextImpl ctx = new ELContextImpl(expressionFactory);
+            ELContextImpl ctx = new ELContextImpl();
             ctx.setFunctionMapper(this.getFunctionMapper(el));
             ExpressionFactory ef = this.pageInfo.getExpressionFactory();
             try {
@@ -1504,7 +1440,7 @@ class Validator {
 
             class ValidateFunctionMapper extends FunctionMapper {
 
-                private Map<String,Method> fnmap = new HashMap<>();
+                private final Map<String,Method> fnmap = new HashMap<>();
 
                 @Override
                 public void mapFunction(String prefix, String localName, Method method) {
@@ -1518,7 +1454,7 @@ class Validator {
             }
 
             class MapperELVisitor extends ELNode.Visitor {
-                private ValidateFunctionMapper fmapper;
+                private final ValidateFunctionMapper fmapper;
 
                 MapperELVisitor(ValidateFunctionMapper fmapper) {
                     this.fmapper = fmapper;
@@ -1541,9 +1477,9 @@ class Validator {
                         err.jspError("jsp.error.function.classnotfound", n.getFunctionInfo().getFunctionClass(),
                                 n.getPrefix() + ':' + n.getName(), e.getMessage());
                     }
-                    String paramTypes[] = n.getParameters();
+                    String[] paramTypes = n.getParameters();
                     int size = paramTypes.length;
-                    Class<?> params[] = new Class[size];
+                    Class<?>[] params = new Class[size];
                     int i = 0;
                     try {
                         for (i = 0; i < size; i++) {
@@ -1623,11 +1559,7 @@ class Validator {
         if (contentType == null || !contentType.contains("charset=")) {
             boolean isXml = page.getRoot().isXmlSyntax();
             String defaultType;
-            if (contentType == null) {
-                defaultType = isXml ? "text/xml" : "text/html";
-            } else {
-                defaultType = contentType;
-            }
+            defaultType = Objects.requireNonNullElse(contentType, isXml ? "text/xml" : "text/html");
 
             String charset = null;
             if (isXml) {
@@ -1678,10 +1610,9 @@ class Validator {
 
         for (Object o : compiler.getPageInfo().getTaglibs()) {
 
-            if (!(o instanceof TagLibraryInfoImpl)) {
+            if (!(o instanceof TagLibraryInfoImpl tli)) {
                 continue;
             }
-            TagLibraryInfoImpl tli = (TagLibraryInfoImpl) o;
 
             ValidationMessage[] errors = tli.validate(xmlView);
             if ((errors != null) && (errors.length != 0)) {
