@@ -16,6 +16,7 @@
  */
 package org.apache.tomcat.util.descriptor.web;
 
+import java.io.Serial;
 import java.io.Serializable;
 import java.nio.charset.StandardCharsets;
 import java.util.Arrays;
@@ -30,9 +31,12 @@ import org.apache.tomcat.util.buf.UDecoder;
  * <b>WARNING</b>: It is assumed that instances of this class will be created and modified only within the context of a
  * single thread, before the instance is made visible to the remainder of the application. After that, only read access
  * is expected. Therefore, none of the read and write access within this class is synchronized.
+ *
+ * @author Craig R. McClanahan
  */
 public class SecurityCollection extends XmlEncodingBase implements Serializable {
 
+    @Serial
     private static final long serialVersionUID = 1L;
 
     // ----------------------------------------------------------- Constructors
