@@ -1258,8 +1258,8 @@ public abstract class AbstractEndpoint<S, U> {
             } else {
                 return IntrospectionUtils.setProperty(this, name, value, false);
             }
-        } catch (Exception x) {
-            getLog().error(sm.getString("endpoint.setAttributeError", name, value), x);
+        } catch (Exception e) {
+            getLog().error(sm.getString("endpoint.setAttributeError", name, value), e);
             return false;
         }
     }
@@ -1381,7 +1381,9 @@ public abstract class AbstractEndpoint<S, U> {
         try {
             localAddress = getLocalAddress();
         } catch (IOException ioe) {
-            getLog().debug(sm.getString("endpoint.debug.unlock.localFail", getName()), ioe);
+            if (getLog().isDebugEnabled()) {
+                getLog().debug(sm.getString("endpoint.debug.unlock.localFail", getName()), ioe);
+            }
         }
         if (localAddress == null) {
             getLog().warn(sm.getString("endpoint.debug.unlock.localNone", getName()));
