@@ -17,7 +17,6 @@
 package org.apache.tomcat.util.net.openssl.panama;
 
 import java.io.ByteArrayOutputStream;
-import java.io.IOException;
 import java.io.InputStream;
 import java.lang.foreign.Arena;
 import java.lang.foreign.MemorySegment;
@@ -57,7 +56,6 @@ import static org.apache.tomcat.util.openssl.openssl_h_Macros.*;
 import org.apache.juli.logging.Log;
 import org.apache.juli.logging.LogFactory;
 import org.apache.tomcat.util.buf.Asn1Parser;
-import org.apache.tomcat.util.http.Method;
 import org.apache.tomcat.util.net.Constants;
 import org.apache.tomcat.util.net.SSLUtil;
 import org.apache.tomcat.util.net.openssl.ciphers.OpenSSLCipherConfigurationParser;
@@ -69,7 +67,7 @@ import org.apache.tomcat.util.openssl.openssl_h_Compatibility;
 import org.apache.tomcat.util.res.StringManager;
 
 /**
- * Implements a {@link SSLEngine} using <a href="https://docs.openssl.org/master/man3/BIO_s_bio/#examples">OpenSSL BIO
+ * Implements a {@link SSLEngine} using <a href="https://www.openssl.org/docs/crypto/BIO_s_bio.html#EXAMPLE">OpenSSL BIO
  * abstractions</a>.
  */
 public final class OpenSSLEngine extends SSLEngine implements SSLUtil.ProtocolInfo {
@@ -95,8 +93,6 @@ public final class OpenSSLEngine extends SSLEngine implements SSLUtil.ProtocolIn
     private static final int MAX_PLAINTEXT_LENGTH = 16 * 1024; // 2^14
     private static final int MAX_COMPRESSED_LENGTH = MAX_PLAINTEXT_LENGTH + 1024;
     private static final int MAX_CIPHERTEXT_LENGTH = MAX_COMPRESSED_LENGTH + 1024;
-    // 15 minutes aligns with JSSE
-    private static final int OCSP_MAX_SKEW = 60 * 15;
 
     // Header (5) + Data (2^14) + Compression (1024) + Encryption (1024) + MAC (20) + Padding (256)
     private static final int MAX_ENCRYPTED_PACKET_LENGTH = MAX_CIPHERTEXT_LENGTH + 5 + 20 + 256;
@@ -140,7 +136,7 @@ public final class OpenSSLEngine extends SSLEngine implements SSLUtil.ProtocolIn
     private volatile boolean destroyed;
 
     // Use an invalid cipherSuite until the handshake is completed
-    // See https://docs.oracle.com/en/java/javase/11/docs/api/java.base/javax/net/ssl/SSLEngine.html#getSession()
+    // See https://docs.oracle.com/en/java/javase/17/docs/api/java.base/javax/net/ssl/SSLEngine.html#getSession()
     private volatile String version;
     private volatile String cipher;
     private volatile String applicationProtocol;
@@ -177,15 +173,10 @@ public final class OpenSSLEngine extends SSLEngine implements SSLUtil.ProtocolIn
      *                                                verification from the {@code SSL_CTX} {@code sslCtx}
      * @param certificateVerificationDepth        Certificate verification depth
      * @param certificateVerificationOptionalNoCA Skip CA verification in optional mode
-     * @param noOcspCheck                         Enable OCSP if true
-     * @param ocspSoftFail                        Allow OCSP checks to pass if the responder can't be contacted
-     * @param ocspTimeout                         Timout in ms to use for OCSP requests
-     * @param ocspVerifyFlags                     Verification flags for OCSP
      */
     OpenSSLEngine(Cleaner cleaner, MemorySegment sslCtx, String fallbackApplicationProtocol, boolean clientMode,
             OpenSSLSessionContext sessionContext, boolean alpn, boolean initialized, int certificateVerificationDepth,
-            boolean certificateVerificationOptionalNoCA, boolean noOcspCheck, boolean ocspSoftFail,
-            int ocspTimeout, int ocspVerifyFlags) {
+            boolean certificateVerificationOptionalNoCA, boolean noOcspCheck) {
         if (sslCtx == null) {
             throw new IllegalArgumentException(sm.getString("engine.noSSLContext"));
         }
@@ -208,8 +199,7 @@ public final class OpenSSLEngine extends SSLEngine implements SSLUtil.ProtocolIn
             var internalBIO = internalBIOPointer.get(ValueLayout.ADDRESS, 0);
             var networkBIO = networkBIOPointer.get(ValueLayout.ADDRESS, 0);
             SSL_set_bio(ssl, internalBIO, internalBIO);
-            state = new EngineState(ssl, networkBIO, certificateVerificationDepth, noOcspCheck, ocspSoftFail,
-                    ocspTimeout, ocspVerifyFlags);
+            state = new EngineState(ssl, networkBIO, certificateVerificationDepth, noOcspCheck);
         }
         this.fallbackApplicationProtocol = fallbackApplicationProtocol;
         this.clientMode = clientMode;
@@ -1143,13 +1133,10 @@ public final class OpenSSLEngine extends SSLEngine implements SSLUtil.ProtocolIn
                     (errnum == X509_V_ERR_SELF_SIGNED_CERT_IN_CHAIN()) ||
                     (errnum == X509_V_ERR_UNABLE_TO_GET_ISSUER_CERT_LOCALLY()) ||
                     (errnum == X509_V_ERR_CERT_UNTRUSTED()) || (errnum == X509_V_ERR_UNABLE_TO_VERIFY_LEAF_SIGNATURE());
-            if ((verifyErrorIsOptional || errnum == X509_V_OK()) && (state.certificateVerifyMode == OpenSSLContext.OPTIONAL_NO_CA)) {
+            if (verifyErrorIsOptional && (state.certificateVerifyMode == OpenSSLContext.OPTIONAL_NO_CA)) {
                 ok = 1;
                 openssl_h_Compatibility.SSL_set_verify_result(state.ssl, X509_V_OK());
             }
-            if (ok == 0 && errnum == X509_V_ERR_UNABLE_TO_GET_CRL()) {
-                ok = 1;
-            }
             /*
              * Expired certificates vs. "expired" CRLs: by default, OpenSSL turns X509_V_ERR_CRL_HAS_EXPIRED into a
              * "certificate_expired(45)" SSL alert, but that's not really the message we should convey to the peer (at
@@ -1170,18 +1157,19 @@ public final class OpenSSLEngine extends SSLEngine implements SSLUtil.ProtocolIn
                  * issuer may be missing/untrusted. Fail in that case.
                  */
                 if (verifyErrorIsOptional) {
-                    X509_STORE_CTX_set_error(x509ctx, X509_V_ERR_APPLICATION_VERIFICATION());
-                    errnum = X509_V_ERR_APPLICATION_VERIFICATION();
-                    ok = 0;
+                    if (state.certificateVerifyMode != OpenSSLContext.OPTIONAL_NO_CA) {
+                        X509_STORE_CTX_set_error(x509ctx, X509_V_ERR_APPLICATION_VERIFICATION());
+                        errnum = X509_V_ERR_APPLICATION_VERIFICATION();
+                        ok = 0;
+                    }
                 } else {
-                    int ocspResponse = processOCSP(state, x509ctx);
+                    int ocspResponse = processOCSP(x509ctx);
                     if (ocspResponse == V_OCSP_CERTSTATUS_REVOKED()) {
                         ok = 0;
                         errnum = X509_STORE_CTX_get_error(x509ctx);
-                        X509_STORE_CTX_set_error(x509ctx, X509_V_ERR_CERT_REVOKED());
                     } else if (ocspResponse == V_OCSP_CERTSTATUS_UNKNOWN()) {
                         errnum = X509_STORE_CTX_get_error(x509ctx);
-                        if (errnum != 0 && !(state.ocspSoftFail && errnum == X509_V_ERR_UNABLE_TO_GET_CRL())) {
+                        if (errnum <= 0) {
                             ok = 0;
                         }
                     }
@@ -1196,7 +1184,7 @@ public final class OpenSSLEngine extends SSLEngine implements SSLUtil.ProtocolIn
         }
     }
 
-    private static int processOCSP(EngineState state, MemorySegment /* X509_STORE_CTX */ x509ctx) {
+    private static int processOCSP(MemorySegment /* X509_STORE_CTX */ x509ctx) {
         int ocspResponse = V_OCSP_CERTSTATUS_UNKNOWN();
         MemorySegment x509 = X509_STORE_CTX_get_current_cert(x509ctx);
         if (!MemorySegment.NULL.equals(x509)) {
@@ -1207,60 +1195,47 @@ public final class OpenSSLEngine extends SSLEngine implements SSLUtil.ProtocolIn
                 // don't do OCSP checking for valid self-issued certs
                 X509_STORE_CTX_set_error(x509ctx, X509_V_OK());
             } else {
-                try (var localArena = Arena.ofConfined()) {
-                    // If we can't get the issuer, we cannot perform OCSP verification
-                    MemorySegment issuer = MemorySegment.NULL;
-                    try {
-                        if (openssl_h_Compatibility.OPENSSL && !openssl_h_Compatibility.OPENSSL3) {
-                            issuer = openssl_h_Compatibility.X509_STORE_CTX_get0_current_issuer(x509ctx);
-                        } else {
-                            MemorySegment x509IssuerPointer = localArena.allocateFrom(ValueLayout.ADDRESS, MemorySegment.NULL);
-                            int res = X509_STORE_CTX_get1_issuer(x509IssuerPointer, x509ctx, x509);
-                            if (res > 0) {
-                                issuer = x509IssuerPointer.get(ValueLayout.ADDRESS, 0);
+                // If we can't get the issuer, we cannot perform OCSP verification
+                MemorySegment issuer = X509_STORE_CTX_get0_current_issuer(x509ctx);
+                if (!MemorySegment.NULL.equals(issuer)) {
+                    // sslutils.c ssl_ocsp_request(x509, issuer, x509ctx);
+                    int nid = X509_get_ext_by_NID(x509, NID_info_access(), -1);
+                    if (nid >= 0) {
+                        try (var localArenal = Arena.ofConfined()) {
+                            MemorySegment ext = X509_get_ext(x509, nid);
+                            MemorySegment os = X509_EXTENSION_get_data(ext);
+                            int length = ASN1_STRING_length(os);
+                            MemorySegment data = ASN1_STRING_get0_data(os);
+                            // ocsp_urls = decode_OCSP_url(os);
+                            byte[] asn1String =
+                                    data.reinterpret(length, localArenal, null).toArray(ValueLayout.JAVA_BYTE);
+                            Asn1Parser parser = new Asn1Parser(asn1String);
+                            // Parse the byte sequence
+                            ArrayList<String> urls = new ArrayList<>();
+                            try {
+                                parseOCSPURLs(parser, urls);
+                            } catch (Exception e) {
+                                log.error(sm.getString("engine.ocspParseError"), e);
                             }
-                        }
-                        if (!MemorySegment.NULL.equals(issuer)) {
-                            // sslutils.c ssl_ocsp_request(x509, issuer, x509ctx);
-                            int nid = X509_get_ext_by_NID(x509, NID_info_access(), -1);
-                            if (nid >= 0) {
-                                MemorySegment ext = X509_get_ext(x509, nid);
-                                MemorySegment os = X509_EXTENSION_get_data(ext);
-                                int length = ASN1_STRING_length(os);
-                                MemorySegment data = ASN1_STRING_get0_data(os);
-                                // ocsp_urls = decode_OCSP_url(os);
-                                byte[] asn1String =
-                                        data.reinterpret(length, localArena, null).toArray(ValueLayout.JAVA_BYTE);
-                                Asn1Parser parser = new Asn1Parser(asn1String);
-                                // Parse the byte sequence
-                                ArrayList<String> urls = new ArrayList<>();
-                                try {
-                                    parseOCSPURLs(parser, urls);
-                                } catch (Exception e) {
-                                    log.error(sm.getString("engine.ocspParseError"), e);
-                                }
-                                if (!urls.isEmpty()) {
-                                    // Use OpenSSL to build OCSP request
-                                    for (String urlString : urls) {
-                                        try {
-                                            URL url = (new URI(urlString)).toURL();
-                                            ocspResponse = processOCSPRequest(state, url, issuer, x509, x509ctx, localArena);
-                                            if (log.isDebugEnabled()) {
-                                                log.debug(sm.getString("engine.ocspResponse", urlString,
-                                                        Integer.toString(ocspResponse)));
-                                            }
-                                        } catch (MalformedURLException | URISyntaxException e) {
-                                            log.warn(sm.getString("engine.invalidOCSPURL", urlString));
-                                        }
-                                        if (ocspResponse != V_OCSP_CERTSTATUS_UNKNOWN()) {
-                                            break;
+                            if (!urls.isEmpty()) {
+                                // Use OpenSSL to build OCSP request
+                                for (String urlString : urls) {
+                                    try {
+                                        URL url = (new URI(urlString)).toURL();
+                                        ocspResponse = processOCSPRequest(url, issuer, x509, x509ctx, localArenal);
+                                        if (log.isDebugEnabled()) {
+                                            log.debug(sm.getString("engine.ocspResponse", urlString,
+                                                    Integer.toString(ocspResponse)));
                                         }
+                                    } catch (MalformedURLException | URISyntaxException e) {
+                                        log.warn(sm.getString("engine.invalidOCSPURL", urlString));
+                                    }
+                                    if (ocspResponse != V_OCSP_CERTSTATUS_UNKNOWN()) {
+                                        break;
                                     }
                                 }
                             }
                         }
-                    } finally {
-                        X509_free(issuer);
                     }
                 }
             }
@@ -1297,11 +1272,8 @@ public final class OpenSSLEngine extends SSLEngine implements SSLUtil.ProtocolIn
         }
     }
 
-    private static int processOCSPRequest(EngineState state, URL url, MemorySegment issuer, MemorySegment x509,
+    private static int processOCSPRequest(URL url, MemorySegment issuer, MemorySegment x509,
             MemorySegment /* X509_STORE_CTX */ x509ctx, Arena localArena) {
-        if (openssl_h_Compatibility.BORINGSSL || openssl_h_Compatibility.isLibreSSLPre35()) {
-            return V_OCSP_CERTSTATUS_UNKNOWN();
-        }
         MemorySegment ocspRequest = MemorySegment.NULL;
         MemorySegment ocspResponse = MemorySegment.NULL;
         MemorySegment id;
@@ -1322,7 +1294,6 @@ public final class OpenSSLEngine extends SSLEngine implements SSLUtil.ProtocolIn
             if (MemorySegment.NULL.equals(ocspOneReq)) {
                 return V_OCSP_CERTSTATUS_UNKNOWN();
             }
-            OCSP_request_add1_nonce(ocspRequest, (char) 0, -1);
             MemorySegment bufPointer = localArena.allocateFrom(ValueLayout.ADDRESS, MemorySegment.NULL);
             int requestLength = i2d_OCSP_REQUEST(ocspRequest, bufPointer);
             if (requestLength <= 0) {
@@ -1336,9 +1307,7 @@ public final class OpenSSLEngine extends SSLEngine implements SSLUtil.ProtocolIn
             // Content-Length: ocspRequestData.length
             byte[] ocspRequestData = buf.reinterpret(requestLength, localArena, null).toArray(ValueLayout.JAVA_BYTE);
             connection = (HttpURLConnection) url.openConnection();
-            connection.setConnectTimeout(state.ocspTimeout);
-            connection.setReadTimeout(state.ocspTimeout);
-            connection.setRequestMethod(Method.POST);
+            connection.setRequestMethod("POST");
             connection.setDoInput(true);
             connection.setDoOutput(true);
             connection.setFixedLengthStreamingMode(requestLength);
@@ -1359,54 +1328,27 @@ public final class OpenSSLEngine extends SSLEngine implements SSLUtil.ProtocolIn
             var nativeResponseData = localArena.allocateFrom(ValueLayout.JAVA_BYTE, responseData);
             var nativeResponseDataPointer = localArena.allocateFrom(ValueLayout.ADDRESS, nativeResponseData);
             ocspResponse = d2i_OCSP_RESPONSE(MemorySegment.NULL, nativeResponseDataPointer, responseData.length);
-            if (MemorySegment.NULL.equals(ocspResponse)) {
-                // Failed to get a valid response
-                X509_STORE_CTX_set_error(x509ctx, X509_V_ERR_APPLICATION_VERIFICATION());
-            } else {
+            if (!MemorySegment.NULL.equals(ocspResponse)) {
                 if (OCSP_response_status(ocspResponse) == OCSP_RESPONSE_STATUS_SUCCESSFUL()) {
                     basicResponse = OCSP_response_get1_basic(ocspResponse);
-                    if (OCSP_check_nonce(ocspRequest, basicResponse) == 0) {
-                        X509_STORE_CTX_set_error(x509ctx, X509_V_ERR_OCSP_RESP_INVALID());
-                        return V_OCSP_CERTSTATUS_UNKNOWN();
-                    }
-                    MemorySegment certStack = OCSP_resp_get0_certs(basicResponse);
-                    if (OCSP_basic_verify(basicResponse, certStack, X509_STORE_CTX_get0_store(x509ctx), state.ocspVerifyFlags) <= 0) {
-                        X509_STORE_CTX_set_error(x509ctx, X509_V_ERR_OCSP_SIGNATURE_FAILURE());
-                        return V_OCSP_CERTSTATUS_UNKNOWN();
-                    }
                     certId = OCSP_cert_to_id(MemorySegment.NULL, x509, issuer);
                     if (MemorySegment.NULL.equals(certId)) {
-                        X509_STORE_CTX_set_error(x509ctx, X509_V_ERR_OCSP_RESP_INVALID());
                         return V_OCSP_CERTSTATUS_UNKNOWN();
                     }
                     // Find by serial number and get the matching response
                     MemorySegment singleResponse =
                             OCSP_resp_get0(basicResponse, OCSP_resp_find(basicResponse, certId, -1));
-                    MemorySegment thisUpdatePointer = localArena.allocateFrom(ValueLayout.ADDRESS, MemorySegment.NULL);
-                    MemorySegment nextUpdatePointer = localArena.allocateFrom(ValueLayout.ADDRESS, MemorySegment.NULL);
-                    int status = OCSP_single_get0_status(singleResponse, MemorySegment.NULL, MemorySegment.NULL,
-                            thisUpdatePointer, nextUpdatePointer);
-                    if (OCSP_check_validity(thisUpdatePointer.get(ValueLayout.ADDRESS, 0),
-                            nextUpdatePointer.get(ValueLayout.ADDRESS, 0), OCSP_MAX_SKEW, -1) <= 0) {
-                        X509_STORE_CTX_set_error(x509ctx, X509_V_ERR_OCSP_NOT_YET_VALID());
-                        return V_OCSP_CERTSTATUS_UNKNOWN();
-                    }
-                    if (OCSP_check_validity(thisUpdatePointer.get(ValueLayout.ADDRESS, 0),
-                            nextUpdatePointer.get(ValueLayout.ADDRESS, 0), OCSP_MAX_SKEW, OCSP_MAX_SKEW) <= 0) {
-                        X509_STORE_CTX_set_error(x509ctx, X509_V_ERR_OCSP_HAS_EXPIRED());
-                        return V_OCSP_CERTSTATUS_UNKNOWN();
-                    }
-                    return status;
+                    return OCSP_single_get0_status(singleResponse, MemorySegment.NULL, MemorySegment.NULL,
+                            MemorySegment.NULL, MemorySegment.NULL);
                 }
             }
-        } catch (IOException ioe) {
-            // Timeout or network error. Responder is not available.
-            log.warn(sm.getString("engine.ocspRequestError", url.toString()), ioe);
-            X509_STORE_CTX_set_error(x509ctx, X509_V_ERR_UNABLE_TO_GET_CRL());
         } catch (Exception e) {
             log.warn(sm.getString("engine.ocspRequestError", url.toString()), e);
-            X509_STORE_CTX_set_error(x509ctx, X509_V_ERR_APPLICATION_VERIFICATION());
         } finally {
+            if (MemorySegment.NULL.equals(ocspResponse)) {
+                // Failed to get a valid response
+                X509_STORE_CTX_set_error(x509ctx, X509_V_ERR_APPLICATION_VERIFICATION());
+            }
             OCSP_CERTID_free(certId);
             OCSP_BASICRESP_free(basicResponse);
             OCSP_RESPONSE_free(ocspResponse);
@@ -1631,7 +1573,7 @@ public final class OpenSSLEngine extends SSLEngine implements SSLUtil.ProtocolIn
         }
 
         private Principal principal(Certificate[] certs) {
-            return ((java.security.cert.X509Certificate) certs[0]).getSubjectX500Principal();
+            return ((java.security.cert.X509Certificate) certs[0]).getIssuerX500Principal();
         }
 
         @Override
@@ -1710,22 +1652,16 @@ public final class OpenSSLEngine extends SSLEngine implements SSLUtil.ProtocolIn
         private final MemorySegment networkBIO;
         private final int certificateVerificationDepth;
         private final boolean noOcspCheck;
-        private final boolean ocspSoftFail;
-        private final int ocspTimeout;
-        private final int ocspVerifyFlags;
 
         private PHAState phaState = PHAState.NONE;
         private int certificateVerifyMode = 0;
         private int handshakeCount = 0;
 
         private EngineState(MemorySegment ssl, MemorySegment networkBIO, int certificateVerificationDepth,
-                boolean noOcspCheck, boolean ocspSoftFail, int ocspTimeout, int ocspVerifyFlags) {
+                boolean noOcspCheck) {
             states.put(Long.valueOf(ssl.address()), this);
             this.certificateVerificationDepth = certificateVerificationDepth;
             this.noOcspCheck = noOcspCheck;
-            this.ocspSoftFail = ocspSoftFail;
-            this.ocspTimeout = ocspTimeout;
-            this.ocspVerifyFlags = ocspVerifyFlags;
             // Use another arena to avoid keeping a reference through segments
             // This also allows making further accesses to the main pointers safer
             this.ssl = ssl.reinterpret(ValueLayout.ADDRESS.byteSize(), stateArena, openssl_h::SSL_free);
